OC.L10N.register(
    "files_external",
    {
    "External storages" : "Eksternt lager",
    "Personal" : "Personligt",
    "System" : "System",
    "Grant access" : "Godkend adgang",
    "Error configuring OAuth1" : "Fejl under konfiguration af OAuth1",
    "Please provide a valid app key and secret." : "Angiv venligst gyldig app-nøgle og -hemmelighed.",
    "Error configuring OAuth2" : "Fejl under konfiguration af OAuth2",
    "Generate keys" : "Opret nøgler.",
    "Error generating key pair" : "Fejl under oprettelse af nøglepar",
    "All users. Type to select user or group." : "Alle brugere. Indtast for at vælge bruger eller gruppe.",
    "(group)" : "(gruppe)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilitet med Mac NFD encoding (langsom)",
    "Enable encryption" : "Slå kryptering til",
    "Enable previews" : "Slå forhåndsvisninger til",
    "Enable sharing" : "Slå deling til",
    "Check for changes" : "Tjek for ændringer",
    "Never" : "Aldrig",
    "Once every direct access" : "Kun ved hver direkte tilgang",
    "Read only" : "Skrivebeskyttet",
    "Delete" : "Slet",
    "Admin defined" : "Bestemt af administrator",
    "Delete storage?" : "Slet lager?",
    "Saved" : "Gemt",
    "Saving..." : "Gemmer...",
    "Save" : "Gem",
    "Empty response from the server" : "Svar fra serveren uden data",
    "Couldn't access. Please log out and in again to activate this mount point" : "Kunne ikke forbinde. Log venligst ud og ind igen for at aktivere dette mount point.",
    "Couldn't get the information from the remote server: {code} {type}" : "Kunne ikke få information fra fjern serveren: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Kunne ikke få listen over eksterne mount points: {type}",
    "There was an error with message: " : "Der var et problem med beskeden:",
    "External mount error" : "Ekstern mount fejl",
    "external-storage" : "Eksternt lager",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Kunne ikke få listen over Windows netværk drive mount points: Tomt svar fra serveren",
    "Please enter the credentials for the {mount} mount" : "Indtast venligst brugeroplysningerne for {mount} mount",
    "Username" : "Brugernavn",
    "Password" : "Kodeord",
    "Credentials saved" : "Brugeroplysninger gemt",
    "Credentials saving failed" : "Det mislykkedes at gemme brugeroplysninger.",
    "Credentials required" : "Kræver brugeroplysninger ",
    "Storage with ID \"%d\" not found" : "Lagring med ID \"%d\" ikke fundet",
    "Invalid backend or authentication mechanism class" : "Ugyldig backend eller klasse for godkendelsesmekanisme",
    "Invalid mount point" : "Fokert monteringspunkt",
    "Objectstore forbidden" : "Objectstore er forbudt",
    "Invalid storage backend \"%s\"" : "Forkert lager til backend \"%s\"en",
    "Not permitted to use backend \"%s\"" : "Ikke tilladt at bruge backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Ikke tilladt at bruge autorisation mekanismen \"%s\"",
    "Unsatisfied backend parameters" : "Utilfredsstillede backend-parametre",
    "Unsatisfied authentication mechanism parameters" : "Utilfredsstillede parametre for godkendelsesmekanisme",
    "Insufficient data: %s" : "Utilstrækkelige data: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Lageret med id \"%d\" kan ikke redigeres af bruger",
    "Access key" : "Adgangsnøgle",
    "Secret key" : "Hemmelig nøgle",
    "Builtin" : "Indbygget",
    "None" : "Ingen",
    "OAuth1" : "OAuth1",
    "App key" : "App-nøgle",
    "App secret" : "App-hemmelighed",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klient-ID",
    "Client secret" : "Klient hemmelighed",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Lejernavn",
    "Identity endpoint URL" : "Identificer afslutnings URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domæne",
    "Rackspace" : "Hyldeplads",
    "API key" : "API nøgle",
    "Global credentials" : "Globale brugeroplysninger",
    "Log-in credentials, save in database" : "Log-in brugeroplysninger, gem i database",
    "Username and password" : "Brugernavn og kodeord",
    "Log-in credentials, save in session" : "Log-in brugeroplysninger, gem i session",
    "User entered, store in database" : "Bruger indtastet, gem i database",
    "RSA public key" : "RSA offentlig nøgle",
    "Public key" : "Offentlig nøgle",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Værtsnavn",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "Aktivér SSL",
    "Enable Path Style" : "Aktivér stil for sti",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Fjernundermappe",
    "Secure https://" : "Sikker https://",
    "FTP" : "FTP",
    "Host" : "Vært",
    "Secure ftps://" : "Sikker ftps://",
    "Local" : "Lokal",
    "Location" : "Placering",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP med hemmelig nøglelogin",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Del",
    "Show hidden files" : "Vis skjulte filer",
    "SMB / CIFS using OC login" : "SMB / CIFS med OC-login",
    "Username as share" : "Brugernavn som deling",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Tjenestenavn",
    "Request timeout (seconds)" : "Anmodning timeout (sekunder)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL-understøttelsen i PHP er enten ikke aktiveret eller installeret. Monteringen af %s er ikke mulig. Anmod din systemadministrator om at installere det.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP understøttelsen i PHP er enten ikke aktiveret eller installeret. Montering af %s er ikke muligt. Anmod din systemadministrator om at installere det.",
    "Name" : "Navn",
    "Storage type" : "Lagertype",
    "Scope" : "Anvendelsesområde",
    "Open documentation" : "Åbn dokumentation",
    "Folder name" : "Mappenavn",
    "External storage" : "Eksternt lager",
    "Authentication" : "Godkendelse",
    "Configuration" : "Opsætning",
    "Available for" : "Tilgængelig for",
    "Add storage" : "Tilføj lager",
    "Advanced settings" : "Avancerede indstillinger",
    "Allow users to mount external storage" : "Tillad brugere at montere eksternt lager"
},
"nplurals=2; plural=(n != 1);");
